NAME

Mail::POPRelay::Daemon - Dynamic Relay Access Control Daemon Class

SYNOPSIS

Please see README.

DESCRIPTION

The daemon class of POPRelay.

DIAGNOSTICS

die(). Will write to syslog eventually.

SIGNALS

Described below are the actions taken for recieving various signals.

HUP

The config file is reloaded and the relay file is regenerated.

KILL

The relay file is wiped clean.

TERM

The relay file is wiped clean.

CONTRIBUTE

If you feel compelled to write a subclass of POPRelay::Daemon, please sent it to the author for incorporation into the next release.

AUTHOR

Keith Hoerling <keith@hoerling.com>

SEE ALSO

Mail::POPRelay(3pm), poprelay_cleanup(1p).

1 POD Error

The following errors were encountered while parsing the POD:

Around line 104:

You can't have =items (as at line 108) unless the first thing after the =over is an =item